from __future__ import print_function
from random import Random
from fractions import *
import os
import math

# Very temporary code

MAX_N = 500000
MAX_COORD = 10000000
MAX_HALF = MAX_COORD / 2

def generate_convex_displaced(n, seed):
    random = Random()
    random.seed(seed)

    n /= 2

    # Generates a convex polygon with n nodes by picking points on a circle
    # Then adds another n points in between each segment in the convex polygon
    # and displaces it inwards.
    # The solution is then a polygon with n nodes, half of them different from the input data.

    angles = []
    for i in range(n):
        if seed == 0:
            angles.append(math.pi * 2 / n * i)
        else:
            angles.append(random.random() * math.pi * 2)

    start = [(int(round(math.cos(a) * MAX_HALF + MAX_HALF)), int(round(math.sin(a) * MAX_HALF + MAX_HALF)))
             for a in sorted(angles, reverse=True)]

    n = len(start)

    input = []
    for i in range(n):
        (x1,y1) = start[i]
        (x2,y2) = start[(i+1)%n]
        if x1==x2 and y1==y2:
            continue
        (nx,ny) = ((x1+x2)/2.0, (y1+y2)/2.0)
        xdif = x2-x1
        ydif = y2-y1
        length=math.sqrt(xdif*xdif+ydif*ydif)
        nx += ydif / length
        ny -= xdif / length

        input.append((x1,y1))
        input.append((int(nx), int(ny)))

    return input

def generate_star(N):
    r1 = MAX_HALF - MAX_HALF/10
    r2,r3 = r1 + r1/20, r1 + r1/10
    input = []
    for i in range(N):
        phi = -i * math.pi * 2.0 / N
        if i % 2:
            r = r1
        elif i % 4:
            r = r3
        else:
            r = r2
        x,y = math.cos(phi) * r, math.sin(phi) * r
        input.append((int(x)+MAX_HALF, int(y)+MAX_HALF))

    return input


def max_convex(max_coord):
    max_coord /= 2
    tot = 0
    dy = 1
    steps = []
    while tot + dy + 1 <= max_coord:
        for dx in range(dy):
            if gcd(dx, dy) == 1 and tot + dx + dy + 1 <= max_coord:
                steps.append((dx, dy))
                tot += dx + dy
        dy += 1
    steps.sort(key = lambda (x, y): Fraction(x, y))
    steps = steps + [(1,1)] + [(y,x) for (x, y) in reversed(steps)]
    steps.pop()
    (x, y) = (-tot, 0)
    P = []
    for (dx, dy) in steps:
        P.append((x, y))
        x += dx
        y += dy
    for (dx, dy) in steps:
        P.append((x, y))
        x += dy
        y -= dx
    for (dx, dy) in steps:
        P.append((x, y))
        x -= dx
        y -= dy
    for (dx, dy) in steps:
        P.append((x, y))
        x -= dy
        y += dx
    return [(x+max_coord, y+max_coord) for (x,y) in P]


case_no = 0

def output(name, data):
    global case_no
    case_no += 1
    if '%d' in name:
        name = name % len(data)
    with open("%d-%s.in" % (case_no, name), "wt") as f:
        f.write('%d\n' % len(data))
        for (x,y) in data:
            f.write('%d %d\n' % (x, y))

def clear():
    for file in os.listdir('.'):
        (name, ext) = os.path.splitext(file)
        if ext in ['.in', '.ans']:
            os.remove(file)

triangle = [(198, 165), (322, 122), (242, 84)]
colinear_square = [(0, 250), (30, 250), (125, 250), (180, 250), (250, 250), (250, 100), (250, 80), (250, 0), (140, 0), (100, 0), (73, 0), (0, 0), (0, 2), (0, 30), (0, 90)]
uniform_octa_d = [(146, 145), (109, 229), (139, 301), (164, 385), (221, 433), (309, 419), (405, 420), (447, 369), (501, 308), (498, 229), (471, 150), (456, 75), (391, 39), (308, 47), (227, 39), (166, 73)]
zero_area = [(160, 210), (200, 210), (200, 300), (280, 300), (200, 170), (200, 80)]
diamond = [(198, 165), (230, 113), (246, 117), (281, 161), (266, 36), (247, 68), (228, 79), (200, 30)]
manual1 = [(198, 165), (274, 226), (258, 318), (297, 348), (339, 309), (372, 360), (336, 265), (347, 203), (388, 161), (346, 123), (306, 155), (293, 87), (261, 112), (242, 84)]
precision = [(252247, 65698), (244797, 70121), (237347, 74544), (378396, 24279)]

if __name__ == "__main__":
    clear()

    output('triangle', triangle)
    output('colinear-squad', colinear_square)
    output('uniform-octa-d', uniform_octa_d)
    output('zero-area', zero_area)
    output('diamond', diamond)
    output('manual1', manual1)

    large_sizes = [150, 1000, MAX_N / 10, MAX_N / 2, MAX_N]

    for size in large_sizes:
        output('convex_disp_%d', generate_convex_displaced(size, size if size < 1000 else 0))

    for size in large_sizes:
        output('star_%d', generate_star(size))

    coord = MAX_COORD
    while coord >= 1000:
        coord /= 10
    while coord <= MAX_COORD:
        data = max_convex(coord)
        output('max_convex_%d', data)
        random = Random()
        random.seed(coord)
        max_displacement = int(coord*0.01)
        for _ in range(3):
            c=random.randint(0,len(data)-1)
            (x,y) = data[c]
            #x += random.randint(-max_displacement, max_displacement)
            #y += random.randint(-max_displacement, max_displacement)
            dx = (x-coord/2)
            dy = (y-coord/2)
            dlen = math.sqrt(dx*dx+dy*dy)
            x -= int(dx*2/dlen)
            y -= int(dy*2/dlen)
            data[c] = (x,y)
        output('max_convex_adj_%d', data)
        coord *= 10

    #output('precision', precision)
